==> wire-swift-generator-4.1.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-field/-encode-mode/index.md <==
//[wire-schema](../../../../index.md)/[com.squareup.wire.schema](../../index.md)/[Field](../index.md)/[EncodeMode](index.md)

# EncodeMode

[common]\
enum [EncodeMode](index.md) : [Enum](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-enum/index.html)&lt;[Field.EncodeMode](index.md)&gt;

## Entries

| | |
|---|---|
| [MAP](-m-a-p/index.md) | [common]<br>[MAP](-m-a-p/index.md)()<br>Map. |
| [PACKED](-p-a-c-k-e-d/index.md) | [common]<br>[PACKED](-p-a-c-k-e-d/index.md)()<br>Packed encoded list. |
| [REPEATED](-r-e-p-e-a-t-e-d/index.md) | [common]<br>[REPEATED](-r-e-p-e-a-t-e-d/index.md)()<br>List. |
| [OMIT_IDENTITY](-o-m-i-t_-i-d-e-n-t-i-t-y/index.md) | [common]<br>[OMIT_IDENTITY](-o-m-i-t_-i-d-e-n-t-i-t-y/index.md)()<br>Non-repeated fields in proto3. Identify can be 0, false, "", or null. |
| [REQUIRED](-r-e-q-u-i-r-e-d/index.md) | [common]<br>[REQUIRED](-r-e-q-u-i-r-e-d/index.md)()<br>Required from proto2. |
| [NULL_IF_ABSENT](-n-u-l-l_-i-f_-a-b-s-e-n-t/index.md) | [common]<br>[NULL_IF_ABSENT](-n-u-l-l_-i-f_-a-b-s-e-n-t/index.md)()<br>Optional, or OneOf from proto2. |

## Properties

| Name | Summary |
|---|---|
| [name](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-372974862%2FProperties%2F-876600652) | [common]<br>val [name](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-372974862%2FProperties%2F-876600652): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-739389684%2FProperties%2F-876600652) | [common]<br>val [ordinal](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-739389684%2FProperties%2F-876600652): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |

==> wire-swift-generator-4.5.2-javadoc.jar: wire-schema/com.squareup.wire.schema/-field/-encode-mode/index.md <==
//[wire-schema](../../../../index.md)/[com.squareup.wire.schema](../../index.md)/[Field](../index.md)/[EncodeMode](index.md)

# EncodeMode

[common]\
enum [EncodeMode](index.md) : [Enum](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-enum/index.html)&lt;[Field.EncodeMode](index.md)&gt;

## Entries

| | |
|---|---|
| [MAP](-m-a-p/index.md) | [common]<br>[MAP](-m-a-p/index.md)()<br>Map. |
| [PACKED](-p-a-c-k-e-d/index.md) | [common]<br>[PACKED](-p-a-c-k-e-d/index.md)()<br>Packed encoded list. |
| [REPEATED](-r-e-p-e-a-t-e-d/index.md) | [common]<br>[REPEATED](-r-e-p-e-a-t-e-d/index.md)()<br>List. |
| [OMIT_IDENTITY](-o-m-i-t_-i-d-e-n-t-i-t-y/index.md) | [common]<br>[OMIT_IDENTITY](-o-m-i-t_-i-d-e-n-t-i-t-y/index.md)()<br>Non-repeated fields in proto3. Identity can be 0, false, "", or null. |
| [REQUIRED](-r-e-q-u-i-r-e-d/index.md) | [common]<br>[REQUIRED](-r-e-q-u-i-r-e-d/index.md)()<br>Required from proto2. |
| [NULL_IF_ABSENT](-n-u-l-l_-i-f_-a-b-s-e-n-t/index.md) | [common]<br>[NULL_IF_ABSENT](-n-u-l-l_-i-f_-a-b-s-e-n-t/index.md)()<br>Optional, or OneOf from proto2. |

## Properties

| Name | Summary |
|---|---|
| [name](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-372974862%2FProperties%2F-876600652) | [common]<br>val [name](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-372974862%2FProperties%2F-876600652): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-739389684%2FProperties%2F-876600652) | [common]<br>val [ordinal](../../../com.squareup.wire.schema.internal.parser/-option-element/-kind/-s-t-r-i-n-g/index.md#-739389684%2FProperties%2F-876600652): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
